import type { LayoutServerLoad } from "./$types";
import { availableLanguageTags } from "$paraglide/runtime";
import { redirect } from "@sveltejs/kit";

type AvailableLanguages = typeof availableLanguageTags[number];

export const load: LayoutServerLoad = function ({ request, cookies }) {

  const url = new URL(request.url);
  let language = cookies.get("lang") as unknown as AvailableLanguages;
  const acceptLanguage = request.headers.get('accept-language')?.split(",")?.[0]?.split("-")?.[0] as AvailableLanguages;

  if (!language || !availableLanguageTags.includes(language)) {
    if (availableLanguageTags.includes(acceptLanguage)) {
      language = acceptLanguage;
      cookies.set("lang", language);
    } else {
      language = "de"
    }
  }

  if (!url.pathname.startsWith("/" + language) && language !== "de") {
    throw redirect(302, `/${language}/${url.pathname}`.replaceAll("//", "/"))
  }

  return
}
